@@ -205,10 +205,10 @@ void Datum::setAnchor(const util::optional<std::string> &anchor) {
 void Datum::setProperties(
     const util::PropertyMap &properties) // throw(InvalidValueTypeException)
 {
-    std::string publicationDate;
-    properties.getStringValue("PUBLICATION_DATE", publicationDate);
-    if (!publicationDate.empty()) {
-        d->publicationDate = common::DateTime::create(publicationDate);
+    std::string publicationDateResult;
+    properties.getStringValue("PUBLICATION_DATE", publicationDateResult);
+    if (!publicationDateResult.empty()) {
+        d->publicationDate = common::DateTime::create(publicationDateResult);
     }
     ObjectUsage::setProperties(properties);
 }
@@ -1249,7 +1249,7 @@ void GeodeticReferenceFrame::_exportToWKT(
                 if (dbContext) {
                     auto factory = io::AuthorityFactory::create(
                         NN_NO_CHECK(dbContext), std::string());
-                    // We use anonymous autority and approximate matching, so
+                    // We use anonymous authority and approximate matching, so
                     // as to trigger the caching done in createObjectsFromName()
                     // in that case.
                     auto matches = factory->createObjectsFromName(
@@ -1378,13 +1378,13 @@ bool GeodeticReferenceFrame::hasEquivalentNameToUsingAlias(
     if (dbContext) {
         if (!identifiers().empty()) {
             const auto &id = identifiers().front();
-            auto aliases =
+            auto aliasesResult =
                 dbContext->getAliases(*(id->codeSpace()), id->code(), nameStr(),
                                       "geodetic_datum", std::string());
             const char *otherName = other->nameStr().c_str();
-            for (const auto &alias : aliases) {
-                if (metadata::Identifier::isEquivalentName(otherName,
-                                                           alias.c_str())) {
+            for (const auto &aliasResult : aliasesResult) {
+                if (metadata::Identifier::isEquivalentName(
+                        otherName, aliasResult.c_str())) {
                     return true;
                 }
             }
@@ -1397,13 +1397,13 @@ bool GeodeticReferenceFrame::hasEquivalentNameToUsingAlias(
             return false;
         }
 
-        auto aliases =
+        auto aliasesResult =
             dbContext->getAliases(std::string(), std::string(), nameStr(),
                                   "geodetic_datum", std::string());
         const char *otherName = other->nameStr().c_str();
-        for (const auto &alias : aliases) {
+        for (const auto &aliasResult : aliasesResult) {
             if (metadata::Identifier::isEquivalentName(otherName,
-                                                       alias.c_str())) {
+                                                       aliasResult.c_str())) {
                 return true;
             }
         }
